#![no_std]
#![no_main]

use embedded_hal::digital::v2::OutputPin;
use rp_pico::entry;

use panic_halt as _;

use rp_pico::hal::prelude::*;

use rp_pico::hal::pio::{PIOBuilder, PIOExt};

use rp_pico::hal;
use rp_pico::hal::pac;

#[entry]
fn main() -> ! {
    // Grab our singleton objects
    let mut pac = pac::Peripherals::take().unwrap();
    let _core = pac::CorePeripherals::take().unwrap();

    // Set up the watchdog driver - needed by the clock setup code
    let mut watchdog = hal::Watchdog::new(pac.WATCHDOG);

    // Configure the clocks
    let _clocks = hal::clocks::init_clocks_and_plls(
        rp_pico::XOSC_CRYSTAL_FREQ,
        pac.XOSC,
        pac.CLOCKS,
        pac.PLL_SYS,
        pac.PLL_USB,
        &mut pac.RESETS,
        &mut watchdog,
    )
    .ok()
    .unwrap();

    // The single-cycle I/O block controls our GPIO pins
    let sio = hal::Sio::new(pac.SIO);

    // Set the pins up according to their function on this particular board
    let pins = rp_pico::Pins::new(
        pac.IO_BANK0,
        pac.PADS_BANK0,
        sio.gpio_bank0,
        &mut pac.RESETS,
    );

    let (mut pio, sm0, _, _, _) = pac.PIO0.split(&mut pac.RESETS);
    let program = pio_proc::pio_asm!(".wrap_target", "set pins, 1", "set pins, 0", ".wrap").program;
    let installed = pio.install(&program).unwrap();

    let _pin: hal::gpio::Pin<_, hal::gpio::FunctionPio0> = pins.gpio1.into_mode();

    let (mut sm, _rx, _tx) = PIOBuilder::from_program(installed)
        .set_pins(1, 1)
        .build(sm0);
    sm.set_pindirs([(1, hal::pio::PinDir::Output)]);
    let _sm = sm.start();
    
    loop {}
}
